User prompt
when the hero hits cube_fast the cube drop starts before the middle of the screen
User prompt
when a hero hits cube_fast the cube drop starts earlier by 25 percent
User prompt
when a hero hits cube_fast the cube drop starts earlier by 25 percent
User prompt
Fix Bug: 'Uncaught TypeError: Cannot read properties of undefined (reading 'onComplete')' in or related to this line: 'LK.loader.onComplete.add(function () {});' Line Number: 251
User prompt
don't start the game until all the assets are loaded.
User prompt
redo alarm and alarm2 blinks, make them blink three times, with a period of 1 time per second.
User prompt
Between cube_fast and cube_collapse there should be a gap of at least two columns
User prompt
put one cube_collapse in every 22 columns in front of the hero
User prompt
Between cube_fast and cube_collapse there should be a gap of at least two columns
User prompt
cube_fast and cube_collapse must not be in neighboring columns
User prompt
cube_fast and cube_collapse must not be in neighboring columns
User prompt
don't put cube_fast and cube_collapse next to each other.
User prompt
don't put cube_fast and cube_collapse next to each other.
User prompt
cube_fast and cube_collapse should always be placed at the very top of the posts
User prompt
cube_fast and cube_collapse should always be placed on top
User prompt
make the mutual arrangement of cube_fast and cube_collapse more randomized
User prompt
Alarm2 down 300
User prompt
Alarm2 blinks 2 times once per second
User prompt
put one cube_collapse in every 17 columns in front of the hero
User prompt
put one cube_collapse in every 17 columns in front of the hero
User prompt
display Alarm2 in the upper right corner of the screen when the hero hits cube_fast
User prompt
Fix Bug: 'Uncaught ReferenceError: AlarmDisplay is not defined' in or related to this line: 'var alarmDisplay = game.addChild(new AlarmDisplay());' Line Number: 219
User prompt
display Alarm2 in the upper right corner of the screen when the hero hits cube_fast
User prompt
there should be no cube_fast and cube_collapse in the first 100 columns
User prompt
place one cube_fast in every 10 column in front of the player
===================================================================
--- original.js
+++ change.js
@@ -199,19 +199,19 @@
anchorX: 1.0,
anchorY: 0.0
});
self.x = 2048 - 50; // Position to the right by 50
- self.y = 50; // Position down by 50
+ self.y = 350; // Position down by 350
self.visible = false; // Initially not visible
self.show = function () {
self.visible = true;
var flashInterval = LK.setInterval(function () {
self.visible = !self.visible;
- }, 250);
+ }, 500);
LK.setTimeout(function () {
LK.clearInterval(flashInterval);
self.hide();
- }, 2000);
+ }, 5000);
};
self.hide = function () {
self.visible = false;
};
girl sitting on Wrecking Ball, cartoon style.. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows.
construction cranes on the sides of the frame, depth of field blur, cartoon style, black and white. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows.
"ALARM" text bubble, comic style. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows.
the surface is gray, concrete with a black square in the center. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows.
Wrecking Ball with eyes, cartoon style.. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows.
the surface is red, concrete with a black square in the center.. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows.
"ALARM" text bubble yellow, comic book style.. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows.
the surface is yellow, concrete with a black square in the center. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows.